// SPDX-License-Identifier: MIT
// This file is part of Freecell Solver. It is subject to the license terms in
// the LICENSE file found in the top-level directory of this distribution
// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
// Freecell Solver, including this file, may be copied, modified, propagated,
// or distributed except according to the terms contained in the LICENSE file.
//
// Copyright (c) 2016 Shlomi Fish
// count.h - define the COUNT macro.
#pragma once

#define COUNT(arr) (sizeof(arr) / sizeof(arr[0]))
#define LAST(arr) (arr)[COUNT(arr) - 1]
