// SPDX-License-Identifier: MIT
// This file is part of Freecell Solver. It is subject to the license terms in
// the LICENSE file found in the top-level directory of this distribution
// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
// Freecell Solver, including this file, may be copied, modified, propagated,
// or distributed except according to the terms contained in the LICENSE file.
//
// Copyright (c) 2000 Shlomi Fish
#pragma once

#include <stdio.h>
#include <stdarg.h>
#include <stdlib.h>

static inline __attribute__((noreturn))
__attribute__((format(printf, 1, 2))) void
exit_error(const char *msg, ...)
{
    va_list ap;

    va_start(ap, msg);
    vfprintf(stderr, msg, ap);
    va_end(ap);
    exit(-1);
}
